@@ -1,5 +1,7 @@
 # These functions are
-# Copyright (C) 1998-2007 T.W. Yee, University of Auckland. All rights reserved.
+# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# All rights reserved.
+
 
 
 
@@ -25,22 +27,23 @@ cao  <- function(formula,
 
     ocall <- match.call()
 
-    if(smart) 
+    if (smart) 
         setup.smart("write")
 
     mt <- terms(formula, data = data)
-    if(missing(data)) 
+    if (missing(data)) 
         data <- environment(formula)
 
-    mf <- match.call(expand=FALSE)
-    mf$family <- mf$method <- mf$model <- mf$x.arg <- mf$y.arg <- mf$control <-
+    mf <- match.call(expand.dots = FALSE)
+    mf$family <- mf$method <- mf$model <- mf$x.arg <- mf$y.arg <-
+        mf$control <-
         mf$contrasts <- mf$constraints <- mf$extra <- mf$qr.arg <- NULL
     mf$coefstart <- mf$etastart <- mf$... <- NULL
     mf$smart <- NULL
     mf$drop.unused.levels <- TRUE 
     mf[[1]] <- as.name("model.frame")
     mf <- eval(mf, parent.frame()) 
-    if(method == "model.frame")
+    if (method == "model.frame")
         return(mf)
     na.act <- attr(mf, "na.action")
 
@@ -54,42 +57,42 @@ cao  <- function(formula,
 
     y <- model.response(mf, "numeric") # model.extract(mf, "response")
     x <- model.matrix(mt, mf, contrasts)
-    attr(x, "assign") <- attrassigndefault(x, mt) # So as to make it like Splus
+    attr(x, "assign") = attrassigndefault(x, mt)
     offset <- model.offset(mf)
-    if(is.null(offset)) 
+    if (is.null(offset)) 
         offset <- 0 # yyy ???
     w <- model.weights(mf)
-    if(!length(w))
+    if (!length(w))
         w <- rep(1, nrow(mf))
-    else if(ncol(as.matrix(w))==1 && any(w < 0))
+    else if (ncol(as.matrix(w))==1 && any(w < 0))
         stop("negative weights not allowed")
 
-    if(is.character(family))
+    if (is.character(family))
         family <- get(family)
-    if(is.function(family))
+    if (is.function(family))
         family <- family()
-    if(!inherits(family, "vglmff")) {
-        stop(paste("family=", family, "is not a VGAM family function"))
+    if (!inherits(family, "vglmff")) {
+        stop("'family=", family, "' is not a VGAM family function")
     }
 
     eval(vcontrol.expression)
 
-    if(!is.null(family@first))
+    if (!is.null(family@first))
         eval(family@first)
 
 
     cao.fitter <- get(method)
 
 
-    deviance.Bestof = rep(as.numeric(NA), len=control$Bestof)
+    deviance.Bestof = rep(as.numeric(NA), len = control$Bestof)
     for(tries in 1:control$Bestof) {
-         if(control$trace && (control$Bestof>1)) {
+         if (control$trace && (control$Bestof>1)) {
              cat(paste("\n========================= Fitting model",
                  tries, "=========================\n"))
-             if(exists("flush.console"))
+             if (exists("flush.console"))
                 flush.console()
          }
-         it <- cao.fitter(x=x, y=y, w=w, offset=offset,
+         onefit <- cao.fitter(x=x, y=y, w=w, offset=offset,
                    etastart=etastart, mustart=mustart, coefstart=coefstart,
                    family=family,
                    control=control,
@@ -98,15 +101,16 @@ cao  <- function(formula,
                    extra=extra,
                    qr.arg = qr.arg,
                    Terms=mt, function.name=function.name, ...)
-        deviance.Bestof[tries] = it$crit.list$deviance
-       if(tries==1 || min(deviance.Bestof[1:(tries-1)])>deviance.Bestof[tries])
-            fit = it
+        deviance.Bestof[tries] = onefit$crit.list$deviance
+       if (tries == 1 ||
+           min(deviance.Bestof[1:(tries-1)]) > deviance.Bestof[tries])
+            fit = onefit
     }
     fit$misc$deviance.Bestof = deviance.Bestof
 
     fit$misc$dataname <- dataname
 
-    if(smart) {
+    if (smart) {
         fit$smart.prediction <- get.smart.prediction()
         wrapup.smart()
     }
@@ -120,39 +124,39 @@ cao  <- function(formula,
       "criterion"    = fit$crit.list,
       "family"       = fit$family,
       "misc"         = fit$misc,
-      "model"        = if(model) mf else data.frame(),
+      "model"        = if (model) mf else data.frame(),
       "residuals"    = as.matrix(fit$wresiduals),
       "smart.prediction" = as.list(fit$smart.prediction),
       "terms"        = list(terms=mt))
 
-    if(!smart) answer@smart.prediction <- list(smart.arg=FALSE)
+    if (!smart) answer@smart.prediction <- list(smart.arg=FALSE)
 
-    if(qr.arg) {
+    if (qr.arg) {
         class(fit$qr) = "list"
         slot(answer, "qr") = fit$qr
     }
-    if(length(attr(x, "contrasts")))
+    if (length(attr(x, "contrasts")))
         slot(answer, "contrasts") = attr(x, "contrasts")
-    if(length(fit$fitted.values))
+    if (length(fit$fitted.values))
         slot(answer, "fitted.values") = as.matrix(fit$fitted.values)
-    slot(answer, "na.action") = if(length(na.act)) list(na.act) else list()
-    if(length(offset))
+    slot(answer, "na.action") = if (length(na.act)) list(na.act) else list()
+    if (length(offset))
         slot(answer, "offset") = as.matrix(offset)
-    if(length(fit$weights))
+    if (length(fit$weights))
         slot(answer, "weights") = as.matrix(fit$weights)
-    if(x.arg)
+    if (x.arg)
         slot(answer, "x") = fit$x # The 'small' design matrix
-    if(length(xlev))
+    if (length(xlev))
         slot(answer, "xlevels") = xlev
-    if(y.arg)
+    if (y.arg)
         slot(answer, "y") = as.matrix(fit$y)
 
 
     slot(answer, "control") = fit$control
-    slot(answer, "extra") = if(length(fit$extra)) {
-        if(is.list(fit$extra)) fit$extra else {
-            warning(paste("\"extra\" is not a list, therefore",
-                          "placing \"extra\" into a list"))
+    slot(answer, "extra") = if (length(fit$extra)) {
+        if (is.list(fit$extra)) fit$extra else {
+            warning("'extra' is not a list, therefore ",
+                    "placing 'extra' into a list")
             list(fit$extra)
         }
     } else list() # R-1.5.0
@@ -162,8 +166,8 @@ cao  <- function(formula,
     dimnames(fit$predictors) = list(dimnames(fit$predictors)[[1]],
                                     fit$misc$predictors.names)
     slot(answer, "predictors") = fit$predictors
-    if(length(fit$prior.weights))
-        slot(answer, "prior.weights") = fit$prior.weights
+    if (length(fit$prior.weights))
+        slot(answer, "prior.weights") = as.matrix(fit$prior.weights)
 
 
 
